package eswtshowcase.modules;

import eswtshowcase.DemoModuleListBoxItem;
import org.eclipse.ercp.swt.mobile.Command;
import org.eclipse.ercp.swt.mobile.ListBox;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.events.ControlListener;


/**
 * A class to simplify having many DemoModules grouped together
 */
public class DemoModuleGroup implements DemoModule, SelectionListener, ControlListener {
    protected Shell demoShell;
    
    private DemoModule[] modules;
    private ListBox moduleListBox;
    
    private String title;
    private String description;

    private Shell parentShell;
    
    public DemoModuleGroup(String title, String description, DemoModule[] modules){
        this.title = title;
        this.description = description;
        
        this.modules = modules;
    }
    
    public void runDemo(Shell parent){
    	parentShell = parent;
    	parentShell.addControlListener(this);
        demoShell = new Shell(parent);
        demoShell.setLayout(new FillLayout(SWT.VERTICAL));
        demoShell.setText(title);
        
        Composite demoComposite = new Composite(demoShell, SWT.NONE);
        demoComposite.setLayout(new FillLayout(SWT.VERTICAL));
        
        
        Command backCommand = new Command(demoShell, Command.BACK, 0);
        backCommand.setText("Back");
        backCommand.addSelectionListener(this);
        
       //create a list based on the data in modules
       DemoModuleListBoxItem[] moduleListBoxItems = new DemoModuleListBoxItem[modules.length];
       for(int i=0; i<moduleListBoxItems.length; i++){
           moduleListBoxItems[i] = new DemoModuleListBoxItem(modules[i]);
       }
       
       moduleListBox = new ListBox(demoComposite, SWT.SINGLE, ListBox.LB_STYLE_2LINE_ITEM);
       moduleListBox.addSelectionListener(this);
       moduleListBox.setDataModel(moduleListBoxItems);
       
       demoShell.layout();
       demoShell.open();
    }
    
    public void widgetSelected(SelectionEvent e){
        if(e.widget instanceof Command){
            back();
        }
    }
    
    public void widgetDefaultSelected(SelectionEvent e){
        if(e.widget.equals(moduleListBox)){
            int selection = moduleListBox.getFocusIndex();
            modules[selection].runDemo(demoShell);
        }
    }
    public void controlMoved(ControlEvent e) {
    	
    }
    public void controlResized(ControlEvent e){
    	if (demoShell != null) {
    		demoShell.setLocation(
    				demoShell.getParent().getClientArea().width/2 - demoShell.getBounds().width/2,
    				demoShell.getParent().toDisplay(0,0).y + demoShell.getParent().getClientArea().height - demoShell.getBounds().height);
    	}
    }
    
    private void back(){
        demoShell.dispose();
        demoShell = null;
    }
    
    public String getTitle(){
        return title;
    }
    
    public String getDescription(){
        return description;
    }
}
