/*******************************************************************************
 * Copyright  2010 Nokia Corporation. All rights reserved.
 * Nokia and Nokia Connecting People are registered trademarks of Nokia Corporation.
 * Java and all Java-based marks are trademarks or registered trademarks of Sun Microsystems, Inc.
 * Other product and company names mentioned herein may be trademarks or trade names of their respective owners.
 *
 * Subject to the conditions below, you may, without charge:
 *
 *   Use, copy, modify and/or merge copies of this software and associated documentation files (the Software)
 *
 *   Publish, distribute, sub-license and/or sell new software derived from or incorporating the Software.
 *
 *
 *
 * This license, unmodified, shall be included with all copies or
 * substantial portions of the Software that are distributed in source code form.
 *
 * The Software cannot constitute the primary value of any new software derived from or incorporating the Software.
 *
 * Any person dealing with the Software shall not misrepresent the source of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 *******************************************************************************/
package eswtshowcase.modules;

import org.eclipse.ercp.swt.mobile.CaptionedControl;
import org.eclipse.ercp.swt.mobile.Command;
import org.eclipse.ercp.swt.mobile.TimedMessageBox;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.events.ControlListener;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
//import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.MessageBox;
import org.eclipse.swt.widgets.Shell;

import org.eclipse.swt.custom.ScrolledComposite;
/**
 * A demonstration of the Combo, MessageBox and TimedMessageBox components.
 */
public class ComboMessageBoxDemoModule implements DemoModule, SelectionListener, ControlListener
{
    private Shell demoShell;
    private Composite demoComposite;
    private ScrolledComposite scrolledComposite;
    private Command backCommand;
    private Command displayBoxCommand;

    private Combo typeCombo;
    private Combo iconCombo;
    private Combo textCombo;
    private Combo commandsCombo;

    private CaptionedControl commandsCaption;

    public String getTitle()
    {
        return "Combo & MessageBox";
    }

    public String getDescription()
    {
        return "Demonstrates the Combo and MessageBox components";
    }

    public void runDemo(Shell parent)
    {
        demoShell = new Shell(SWT.MAX);
        demoShell.setText("Combos and MessageBoxes");
        demoShell.setLayout(new FillLayout(SWT.VERTICAL));

        scrolledComposite = new ScrolledComposite(demoShell, SWT.V_SCROLL);
        demoComposite = new Composite(scrolledComposite, SWT.NONE);
        demoComposite.setLayout(new FillLayout(SWT.VERTICAL));
        scrolledComposite.setContent(demoComposite);

        backCommand = new Command(demoShell, Command.EXIT, 0);
        backCommand.setText("Back");
        backCommand.addSelectionListener(this);

        displayBoxCommand = new Command(demoShell, Command.OK, 0);
        displayBoxCommand.setText("Display");
        displayBoxCommand.addSelectionListener(this);

        //Create a combo box for the message box type
        CaptionedControl typeCaption = new CaptionedControl(demoComposite, SWT.NONE);
        typeCaption.setText("Message Box Type");
        typeCombo = new Combo(typeCaption, SWT.DROP_DOWN|SWT.READ_ONLY);
        typeCombo.setItems(new String[] {"MessageBox", "TimedMessageBox"});
        typeCombo.addSelectionListener(this);
        typeCombo.select(0); //select MessageBox initially

        //create a combo box for the icon
        CaptionedControl iconCaption = new CaptionedControl(demoComposite, SWT.NONE);
        iconCaption.setText("Icon");
        iconCombo = new Combo(iconCaption, SWT.DROP_DOWN|SWT.READ_ONLY);
        iconCombo.setItems(new String[] {"Error", "Information", "Question", "Warning", "Working" });
        iconCombo.addSelectionListener(this);
        iconCombo.select(0);

        //create a combo box for the text
        CaptionedControl textCaption = new CaptionedControl(demoComposite, SWT.NONE);
        textCaption.setText("Text");
        textCombo = new Combo(textCaption, SWT.DROP_DOWN);
        textCombo.setItems(new String[] {"This is a message box.", "Hooray!"});
        textCombo.addSelectionListener(this);
        textCombo.select(0);

        //create a combo box for the commands
        commandsCaption = new CaptionedControl(demoComposite, SWT.NONE);
        commandsCaption.setText("Commands");
        commandsCombo = new Combo(commandsCaption, SWT.DROP_DOWN|SWT.READ_ONLY);
        commandsCombo.setItems(new String[] {"OK", "OK & Cancel", "Yes & No", "Yes, No & Cancel", "Retry & Cancel"});
        commandsCombo.addSelectionListener(this);
        commandsCombo.select(0);

        demoShell.layout();
        scrolledComposite.setBounds(scrolledComposite.getParent().getClientArea());
        demoComposite.setSize(demoComposite.computeSize(scrolledComposite.getClientArea().width, SWT.DEFAULT));
        demoComposite.layout();

        demoShell.open();
        demoShell.setActive();
        demoShell.addControlListener(this);
    }

    public void widgetSelected(SelectionEvent e)
    {
        if(e.widget.equals(backCommand))
        {
            back();
        }
        else if(e.widget.equals(displayBoxCommand))
        {
            displayBox();
        }
        else if(e.widget.equals(typeCombo))
        {
            //if the user selects MessageBox he can also choose the buttons
            //a TimedMessageBox doesn't have them so we disable the combo box
            if(typeCombo.getSelectionIndex() == 0)
            {
                commandsCombo.setEnabled(true);
                commandsCaption.setVisible(true);
            }
            else
            {
                commandsCombo.setEnabled(false);
                commandsCaption.setVisible(false);
            }
        }
    }

    public void widgetDefaultSelected(SelectionEvent e)
    {

    }

    public void controlMoved(ControlEvent e)
    {

    }
    public void controlResized(ControlEvent e)
    {
        if(!scrolledComposite.isDisposed())
        {

            scrolledComposite.setRedraw(false);
            scrolledComposite.setBounds(scrolledComposite.getParent().getClientArea());
            demoComposite.setSize(demoComposite.computeSize(scrolledComposite.getClientArea().width, SWT.DEFAULT));
            demoComposite.layout();
            scrolledComposite.setRedraw(true);
        }
    }

    private void back()
    {
        demoShell.dispose();
        demoShell = null;
    }

    private void displayBox()
    {
        int style = getStyle();

        //if it's a message box
        if(typeCombo.getSelectionIndex() == 0)
        {
            //message boxes have buttons, add them to the style
            style |= getCommands();

            //create a MessageBox with the style
            MessageBox box = new MessageBox(demoShell, style);
            box.setMessage(textCombo.getText());
            int result = box.open();

            //here we could test the result type against the buttons the user chose
            //eg. if(result == SWT.YES)
        }
        else
        {
            //create a TimedMessageBox with the style
            TimedMessageBox box = new TimedMessageBox(demoShell, style);
            box.setMessage(textCombo.getText());
            box.open();
        }
    }

    //gets the box style (i.e. icon) depending on the user choice
    private int getStyle()
    {
        switch(iconCombo.getSelectionIndex())
        {
        case 0:
            return SWT.ICON_ERROR;
        case 1:
            return SWT.ICON_INFORMATION;
        case 2:
            return SWT.ICON_QUESTION;
        case 3:
            return SWT.ICON_WARNING;
        case 4:
            return SWT.ICON_WORKING;
        default:
            return SWT.ICON_ERROR;
        }
    }

    //gets the command buttons the user has selected
    private int getCommands()
    {
        switch(commandsCombo.getSelectionIndex())
        {
        case 0:
            return SWT.OK;
        case 1:
            return SWT.OK|SWT.CANCEL;
        case 2:
            return SWT.YES|SWT.NO;
        case 3:
            return SWT.YES|SWT.NO|SWT.CANCEL;
        case 4:
            return SWT.RETRY|SWT.CANCEL;
        default:
            return SWT.OK;
        }
    }
}

